@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.192.2.1 2006/04/03 13:31:04 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c 6796 2007-01-08 22:53:47Z diegoe $
  */
 
 #include "config.h"
@@ -764,7 +764,7 @@ import_dialog_response_cb (GtkDialog *dialog,
 			EphyFileChooser *dialog;
 			GtkFileFilter *filter;
 
-			dialog = ephy_file_chooser_new (_("Import bookmarks from file"),
+			dialog = ephy_file_chooser_new (_("Import Bookmarks from File"),
 							GTK_WIDGET (editor),
 							GTK_FILE_CHOOSER_ACTION_OPEN,
 							NULL, EPHY_FILE_FILTER_NONE);
@@ -901,6 +901,7 @@ cmd_bookmarks_export (GtkAction *action,
 {
 	GtkWidget *dialog, *hbox, *label, *combo;
 	int format;
+	char *filename;
 
 	dialog = GTK_WIDGET (ephy_file_chooser_new (_("Export Bookmarks"),
 		GTK_WIDGET (editor),
@@ -912,14 +913,17 @@ cmd_bookmarks_export (GtkAction *action,
 
 	gtk_file_chooser_set_current_folder
 		(GTK_FILE_CHOOSER (dialog), g_get_home_dir ());
-
+	
+	filename = g_strdup_printf ("%s.%s", _("Bookmarks"), export_formats[0].extension);
 	gtk_file_chooser_set_current_name
-		(GTK_FILE_CHOOSER (dialog), _("Bookmarks"));
+		(GTK_FILE_CHOOSER (dialog), filename);
+	g_free(filename);
 
 	/* Make a format selection combo & label */
-	label = gtk_label_new (_("File format:"));
+	label = gtk_label_new_with_mnemonic (_("File f_ormat:"));
 
 	combo = gtk_combo_box_new_text ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
 
 	for (format = 0; format < G_N_ELEMENTS (export_formats); ++format)
 	{
@@ -933,8 +937,8 @@ cmd_bookmarks_export (GtkAction *action,
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
 	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_end (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
 	gtk_widget_show_all (hbox);
 	
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog), hbox);
@@ -1182,7 +1186,7 @@ ephy_bookmarks_editor_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyBookmarksEditorClass),
 			NULL,
@@ -1362,7 +1366,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		EphyNode *node = selected->data;
 		char name[EPHY_BOOKMARK_ACTION_NAME_BUFFER_SIZE];
 
-		g_return_if_fail (node != NULL);
+		if (node == NULL) return;
 
 		mutable = !ephy_node_get_property_boolean (node, EPHY_NODE_BMK_PROP_IMMUTABLE);
 		
@@ -1870,7 +1874,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, TRUE, TRUE);
 	gtk_widget_show (vbox);
 
-	gtk_box_pack_start (GTK_BOX (vbox),
+	gtk_box_pack_start (GTK_BOX (editor->priv->main_vbox),
 			    build_search_box (editor),
 			    FALSE, FALSE, 0);
 	add_focus_monitor (editor, editor->priv->search_entry);
